METRIC_FORMATS = {
    'CHAR': 'c',
    'COMPLEX': 'dd',
    'DOUBLE': 'd',
    'FLOAT': 'd',
    'HISTOGRAM': 'P',
    'INT': 'i',
    'INT16': 'h',
    'INT32': 'i',
    'INT64': 'q',
    'INT8': 'b',
    'INTEGER': 'q',
    'MAXDOUBLE': 'd',
    'MINDOUBLE': 'd',
    'NDOUBLES': 'P',
    'RATE': 'P',
    'SCALE_FUNC': 'P',
    'SHORT INT': 'h',
    'SIGNED INT': 'i',
    'SIGNED INTEGER': 'q',
    'SIGNED SHORT INT': 'h',
    'TAU_ATOMIC': 'P',
    'UINT16': 'H',
    'UINT32': 'I',
    'UINT64': 'Q',
    'UINT8': 'c',
    'UNSIGNED INT': 'I',
    'UNSIGNED INTEGER': 'Q',
    'UNSIGNED SHORT INT': 'H',
}
